<template>
  <div class="info-rail-list">
    <div class="header">
      <div class="title">
        <span v-if="type === 'list'" class="name">电子围栏列表</span>
        <span v-if="type === 'detail'" class="name">电子围栏信息</span>
      </div>
    </div>
    <!-- 电子围栏列表 -->
    <div v-if="type === 'list'" class="content">
      <div class="rail-card" v-for="(item, index) in data" :key="index">
        <div class="rail-card-title">
          <div class="station-name">{{ item.name }}</div>
          <div class="card-index">序号：{{ index + 1 }}</div>
        </div>
        <div class="rail-card-row">
          <span class="label">所属驻勤点：</span>
          <span class="value">{{ item.stationName }}</span>
        </div>
        <div class="rail-card-row">
          <span class="label">围栏类型：</span>
          <span class="value">{{ item.ruleTypeText }}</span>
        </div>
        <div class="rail-card-row">
          <span class="label">时间范围：</span>
          <span class="value">{{ item.beginTime }} - {{ item.endTime }}</span>
        </div>
        <div class="rail-card-footer">
          <van-button class="btn-info" type="info" @click="showDetail(item)">查看</van-button>
        </div>
      </div>
    </div>
    <!-- 电子围栏详情 -->
    <div v-if="type === 'detail'" class="content content-detail">
      <div class="back-to-list" @click="backToList">&lt; 返回电子围栏列表</div>
      <div class="card-detail">
        <div class="card-detail-item">
          <div class="label">围栏名称：</div>
          <div class="value">{{ detail.name }}</div>
        </div>
        <div class="card-detail-item">
          <div class="label">围栏类型：</div>
          <div class="value">{{ detail.ruleTypeText }}</div>
        </div>
        <div class="card-detail-item">
          <div class="label">所属驻勤点：</div>
          <div class="value">{{ detail.stationName }}</div>
        </div>
        <div class="card-detail-item">
          <div class="label">时间范围：</div>
          <div class="value">{{ detail.beginTime }} - {{ detail.endTime }}</div>
        </div>
        <div class="card-detail-item">
          <div class="label">备注：</div>
          <div class="value">{{ detail.note }}</div>
        </div>
        <div class="card-detail-item">
          <div class="label">驻勤人员：</div>
          <div class="link" @click="showSecurityMan">{{ countOfSecurityMan }}人</div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import { Button } from "vant";

export default {
  name: "infoRailList",
  components: {
    [Button.name]: Button,
  },
  props: {
    data: {
      type: Array,
      default() {
        return [];
      },
    },
    station: Object,
  },
  data() {
    return {
      type: "list",
      detail: {},
    };
  },
  computed: {
    countOfSecurityMan() {
      return this.station?.countOfSecurityMan || 0;
    },
  },
  methods: {
    showDetail(item) {
      this.detail = { ...{}, ...item };
      this.type = "detail";
      this.$emit("showDetail", this.detail, this.station);
    },
    showSecurityMan() {
      this.$emit("showSecurityMan", this.station.id);
    },
    backToList() {
      this.type = "list";
      this.$emit("backToList", this.station);
    },
  },
};
</script>

<style scoped lang="less">
.info-rail-list {
  .header {
    width: 100%;
    height: 58px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    //justify-content: space-between;
    .title {
      display: flex;
      align-items: center;
      .name {
        font-size: 18px;
        font-family: PingFang SC-Medium, PingFang SC, serif;
        font-weight: 500;
        color: #101741;
        line-height: 24px;
      }
    }
  }
  .content {
    width: 100%;
    padding: 8px 12px 0 12px;
    height: calc(80vh - 58px - 44px);
    box-sizing: border-box;
    overflow-x: hidden;
    overflow-y: auto;
    background: #f3f3f3;
    &-detail {
      height: calc(60vh - 58px - 44px);
    }
    .rail-card {
      width: 100%;
      height: 188px;
      background: #ffffff;
      box-shadow: 0 2px 12px 0 rgba(0, 0, 0, 0.04);
      border-radius: 6px 6px 6px 6px;
      margin-bottom: 8px;
      padding: 12px;
      &-title {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 12px;
        .station-name {
          width: 217px;
          font-size: 14px;
          font-family: PingFang SC-Medium, PingFang SC, serif;
          font-weight: 500;
          color: #303133;
          line-height: 22px;
          overflow: hidden;
          text-overflow: ellipsis;
          white-space: nowrap;
        }
        .card-index {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #0f71ff;
          line-height: 22px;
        }
      }
      &-row {
        width: 100%;
        display: flex;
        margin-bottom: 8px;
        .label {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #909399;
          line-height: 22px;
        }
        .value {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #303133;
          line-height: 22px;
        }
      }
      &-footer {
        margin-top: 20px;
        width: 100%;
        display: flex;
        justify-content: flex-end;
        .btn-info {
          width: 80px;
          height: 28px;
          background: #0f71ff;
          border-radius: 6px 6px 6px 6px;
        }
      }
    }
    .back-to-list {
      height: 24px;
      font-size: 14px;
      font-family: PingFang SC-Regular, PingFang SC, serif;
      font-weight: 400;
      color: #0f71ff;
      line-height: 24px;
    }
    .card-detail {
      width: 100%;
      //height: 436px;
      background: #ffffff;
      box-shadow: 0 2px 12px 0 rgba(0, 0, 0, 0.04);
      border-radius: 6px 6px 6px 6px;
      margin-top: 8px;
      padding: 12px;
      &-item {
        padding: 8px 0;
        border-bottom: 1px solid #dcdfe6;
        &:last-child {
          border-bottom: 0;
        }
        .label {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #909399;
          line-height: 22px;
          margin-bottom: 4px;
        }
        .value {
          width: 100%;
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #303133;
          line-height: 22px;
          overflow: hidden;
          text-overflow: ellipsis;
          -webkit-line-clamp: 2;
          display: -webkit-box;
          -webkit-box-orient: vertical;
        }
        .link {
          width: 25px;
          height: 22px;
          font-size: 12px;
          font-family: PingFang SC-Medium, PingFang SC, serif;
          font-weight: 500;
          color: #0f71ff;
          line-height: 22px;
          text-decoration: underline;
        }
      }
    }
  }
}
</style>
